==> kubernetes-model-core-5.0.3-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStateTerminatedFluentImpl<A extends ContainerStateTerminatedFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateTerminatedFluent<A> {

    private String containerID;
    private Integer exitCode;
    private String finishedAt;
    private String message;
    private String reason;
    private Integer signal;
    private String startedAt;

    public ContainerStateTerminatedFluentImpl() {
    }

    public ContainerStateTerminatedFluentImpl(ContainerStateTerminated instance) {
        this.withContainerID(instance.getContainerID()); 
        this.withExitCode(instance.getExitCode()); 
        this.withFinishedAt(instance.getFinishedAt()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withSignal(instance.getSignal()); 
        this.withStartedAt(instance.getStartedAt()); 
    }

    public String getContainerID() {
        return this.containerID;
    }

    public A withContainerID(String containerID) {
        this.containerID=containerID; return (A) this;
    }

    public Boolean hasContainerID() {
        return this.containerID != null;
    }

    public A withNewContainerID(String arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(StringBuilder arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(StringBuffer arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public Integer getExitCode() {
        return this.exitCode;
    }

    public A withExitCode(Integer exitCode) {
        this.exitCode=exitCode; return (A) this;
    }

    public Boolean hasExitCode() {
        return this.exitCode != null;
    }

    public String getFinishedAt() {
        return this.finishedAt;
    }

    public A withFinishedAt(String finishedAt) {
        this.finishedAt=finishedAt; return (A) this;
    }

    public Boolean hasFinishedAt() {
        return this.finishedAt != null;
    }

    public A withNewFinishedAt(String arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(StringBuilder arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(StringBuffer arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getReason() {
        return this.reason;
    }

    public A withReason(String reason) {
        this.reason=reason; return (A) this;
    }

    public Boolean hasReason() {
        return this.reason != null;
    }

    public A withNewReason(String arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1) {
        return (A)withReason(new String(arg1));
    }

    public Integer getSignal() {
        return this.signal;
    }

    public A withSignal(Integer signal) {
        this.signal=signal; return (A) this;
    }

    public Boolean hasSignal() {
        return this.signal != null;
    }

    public String getStartedAt() {
        return this.startedAt;
    }

    public A withStartedAt(String startedAt) {
        this.startedAt=startedAt; return (A) this;
    }

    public Boolean hasStartedAt() {
        return this.startedAt != null;
    }

    public A withNewStartedAt(String arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(StringBuilder arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(StringBuffer arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStateTerminatedFluentImpl that = (ContainerStateTerminatedFluentImpl) o;
        if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
        if (exitCode != null ? !exitCode.equals(that.exitCode) :that.exitCode != null) return false;
        if (finishedAt != null ? !finishedAt.equals(that.finishedAt) :that.finishedAt != null) return false;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        if (signal != null ? !signal.equals(that.signal) :that.signal != null) return false;
        if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerID,  exitCode,  finishedAt,  message,  reason,  signal,  startedAt,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ContainerStateTerminatedFluentImpl<A extends ContainerStateTerminatedFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStateTerminatedFluent<A> {

    private String containerID;
    private Integer exitCode;
    private String finishedAt;
    private String message;
    private String reason;
    private Integer signal;
    private String startedAt;

    public ContainerStateTerminatedFluentImpl() {
    }

    public ContainerStateTerminatedFluentImpl(ContainerStateTerminated instance) {
        this.withContainerID(instance.getContainerID()); 
        this.withExitCode(instance.getExitCode()); 
        this.withFinishedAt(instance.getFinishedAt()); 
        this.withMessage(instance.getMessage()); 
        this.withReason(instance.getReason()); 
        this.withSignal(instance.getSignal()); 
        this.withStartedAt(instance.getStartedAt()); 
    }

    public String getContainerID() {
        return this.containerID;
    }

    public A withContainerID(String containerID) {
        this.containerID=containerID; return (A) this;
    }

    public Boolean hasContainerID() {
        return this.containerID != null;
    }

    public A withNewContainerID(StringBuilder arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(int[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(char[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(StringBuffer arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(byte[] arg1,int arg2) {
        return (A)withContainerID(new String(arg1, arg2));
    }

    public A withNewContainerID(byte[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(char[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withContainerID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewContainerID(String arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public Integer getExitCode() {
        return this.exitCode;
    }

    public A withExitCode(Integer exitCode) {
        this.exitCode=exitCode; return (A) this;
    }

    public Boolean hasExitCode() {
        return this.exitCode != null;
    }

    public A withNewExitCode(int arg1) {
        return (A)withExitCode(new Integer(arg1));
    }

    public String getFinishedAt() {
        return this.finishedAt;
    }

    public A withFinishedAt(String finishedAt) {
        this.finishedAt=finishedAt; return (A) this;
    }

    public Boolean hasFinishedAt() {
        return this.finishedAt != null;
    }

    public A withNewFinishedAt(StringBuilder arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(int[] arg1,int arg2,int arg3) {
        return (A)withFinishedAt(new String(arg1, arg2, arg3));
    }

    public A withNewFinishedAt(char[] arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(StringBuffer arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(byte[] arg1,int arg2) {
        return (A)withFinishedAt(new String(arg1, arg2));
    }

    public A withNewFinishedAt(byte[] arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public A withNewFinishedAt(char[] arg1,int arg2,int arg3) {
        return (A)withFinishedAt(new String(arg1, arg2, arg3));
    }

    public A withNewFinishedAt(byte[] arg1,int arg2,int arg3) {
        return (A)withFinishedAt(new String(arg1, arg2, arg3));
    }

    public A withNewFinishedAt(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withFinishedAt(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewFinishedAt(String arg1) {
        return (A)withFinishedAt(new String(arg1));
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(int[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(char[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(byte[] arg1,int arg2) {
        return (A)withMessage(new String(arg1, arg2));
    }

    public A withNewMessage(byte[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(char[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMessage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getReason() {
        return this.reason;
    }

    public A withReason(String reason) {
        this.reason=reason; return (A) this;
    }

    public Boolean hasReason() {
        return this.reason != null;
    }

    public A withNewReason(StringBuilder arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(int[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(char[] arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(byte[] arg1,int arg2) {
        return (A)withReason(new String(arg1, arg2));
    }

    public A withNewReason(byte[] arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(char[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(byte[] arg1,int arg2,int arg3) {
        return (A)withReason(new String(arg1, arg2, arg3));
    }

    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withReason(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewReason(String arg1) {
        return (A)withReason(new String(arg1));
    }

    public Integer getSignal() {
        return this.signal;
    }

    public A withSignal(Integer signal) {
        this.signal=signal; return (A) this;
    }

    public Boolean hasSignal() {
        return this.signal != null;
    }

    public A withNewSignal(int arg1) {
        return (A)withSignal(new Integer(arg1));
    }

    public String getStartedAt() {
        return this.startedAt;
    }

    public A withStartedAt(String startedAt) {
        this.startedAt=startedAt; return (A) this;
    }

    public Boolean hasStartedAt() {
        return this.startedAt != null;
    }

    public A withNewStartedAt(StringBuilder arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(int[] arg1,int arg2,int arg3) {
        return (A)withStartedAt(new String(arg1, arg2, arg3));
    }

    public A withNewStartedAt(char[] arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(StringBuffer arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(byte[] arg1,int arg2) {
        return (A)withStartedAt(new String(arg1, arg2));
    }

    public A withNewStartedAt(byte[] arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public A withNewStartedAt(char[] arg1,int arg2,int arg3) {
        return (A)withStartedAt(new String(arg1, arg2, arg3));
    }

    public A withNewStartedAt(byte[] arg1,int arg2,int arg3) {
        return (A)withStartedAt(new String(arg1, arg2, arg3));
    }

    public A withNewStartedAt(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withStartedAt(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewStartedAt(String arg1) {
        return (A)withStartedAt(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStateTerminatedFluentImpl that = (ContainerStateTerminatedFluentImpl) o;
        if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
        if (exitCode != null ? !exitCode.equals(that.exitCode) :that.exitCode != null) return false;
        if (finishedAt != null ? !finishedAt.equals(that.finishedAt) :that.finishedAt != null) return false;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        if (signal != null ? !signal.equals(that.signal) :that.signal != null) return false;
        if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerID,  exitCode,  finishedAt,  message,  reason,  signal,  startedAt,  super.hashCode());
    }

}
